Installation
============

You can install pandas-msgpack with ``conda``, ``pip``, or by installing from source.

Conda
-----

.. code-block:: shell

   $ conda install pandas-msgpack --channel conda-forge

This installs pandas-msgpack and all common dependencies, including ``pandas``.

Pip
---

To install the latest version of pandas-msgpack:

.. code-block:: shell

    $ pip install pandas-msgpack -U

This installs pandas-msgpack and all common dependencies, including ``pandas``.


Install from Source
-------------------

.. code-block:: shell

    $ pip install git+https://github.com/pydata/pandas-msgpack.git


Dependencies
------------

- `pandas <https://pypi.python.org/pypi/pandas>`__ ``>=0.19.2``
- `blosc <https://pypi.python.org/pypi/blosc>`__ library can be optionally installed as a compressor.
